[![](https://img.shields.io/pypi/pyversions/imlazy.svg?longCache=True)](https://pypi.org/project/imlazy/)
[![](https://img.shields.io/pypi/v/imlazy.svg?maxAge=3600)](https://pypi.org/project/imlazy/)
[![Travis](https://api.travis-ci.org/smeggingsmegger/imlazy.py.svg?branch=master)](https://travis-ci.org/smeggingsmegger/imlazy.py/)

# I'm Lazy - Simple utilities and libraries that save me time - imlazy

##

#### Installation
```bash
$ [sudo] pip install imlazy
```

#### Functions
function|`__doc__`
-|-
`import_package(package_name)` | Imports a package.
`import_or_install(package_name)` | Imports a package. Installs if not found.

#### Examples
```bash
dockerssh filter
```
